<div align="center">

<h1>
    <img width="500" align="center" src="assets/wordlebee-logo.svg">
</h1>

[![PyPi Version](https://img.shields.io/pypi/v/wordlebee.svg?style=flat-square)](https://pypi.org/project/wordlebee/)
[![PyPi Python versions](https://img.shields.io/pypi/pyversions/wordlebee.svg?style=flat-square)](https://pypi.org/project/wordlebee/)
[![License](https://img.shields.io/badge/license-MIT-blue?style=flat-square)](#license)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](#black)
[![Downloads](https://pepy.tech/badge/wordlebee?style=flat-square)](https://pepy.tech/project/wordlebee)

***A cli wordle word guessing helper bee to solve the wordle puzzle of the day.***

</div>

## Usage

```
python -m wordlebee
```

## Installation

Install `wordlebee` in isolated environment:

```
pipx install wordlebee
```

Install `wordlebee`:

```
pip install wordlebee
```

## Development

Install conda enviroment:

```
conda env create -f environment.yml
```

Install using `poetry`:

```
poetry install
```
